package internal

import (
	"context"
	"fmt"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"plugins/wechat_cpn/internal/vo"
	"strings"
)

// 插件通信信息,若不对应则会报错panic
const (
	Tag         = "wechat_cpn"
	Version     = 1
	CookieKey   = "wechat_cpn"
	CookieValue = "wechat_cpn"
)

type WeChatCpnService struct{}

func (p *WeChatCpnService) Order(ctx context.Context, request *proto.OrderRequest) (*proto.OrderResponse, error) {
	config, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	req, err := orderReq(request.GetOrder(), request.GetProduct())
	if err != nil {
		return nil, err
	}
	svc, err := srv(ctx, config)
	if err != nil {
		return nil, err
	}
	resp, result, err := svc.SendCoupon(ctx, req)
	if err != nil {
		return nil, p.err(ctx, err)
	}
	if result.Response.StatusCode != vo.CodeSuccess.Value() {
		return nil, fmt.Errorf("微信返回错误 Response StatusCode[%d]Status[%s]", result.Response.StatusCode, result.Response.Status)
	}
	return orderResp(request.GetOrder(), *resp.CouponId), nil
}

func (p *WeChatCpnService) Query(ctx context.Context, request *proto.QueryRequest) (*proto.QueryResponse, error) {
	config, err := transConfig(request.Config)
	svc, err := srv(ctx, config)
	if err != nil {
		return nil, err
	}
	req, err := queryReq(request.GetOrder())
	if err != nil {
		return nil, err
	}
	resp, result, err := svc.QueryCoupon(ctx, *req)
	if err != nil {
		return nil, p.err(ctx, err)
	}
	if result.Response.StatusCode != vo.CodeSuccess.Value() {
		return nil, fmt.Errorf("微信返回错误 Response StatusCode[%d]Status[%s]", result.Response.StatusCode, result.Response.Status)
	}
	return queryResp(request, resp), nil
}

func (p *WeChatCpnService) Notify(ctx context.Context, request *proto.NotifyRequest) (*proto.NotifyResponse, error) {
	config, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	if err = verify(ctx, config); err != nil {
		return nil, err
	}
	return notifyResp(), nil
}

func (p *WeChatCpnService) err(_ context.Context, err error) error {
	errStr := err.Error()
	startIndex := strings.Index(errStr, "Message: ")
	if startIndex == -1 {
		return err
	}
	endIndex := strings.Index(errStr[startIndex:], "\n")
	if endIndex == -1 {
		return err
	}
	return fmt.Errorf(errStr[startIndex+len("Message: ") : startIndex+endIndex])
}
