package po

import (
	"encoding/json"
	"fmt"
	"github.com/go-playground/validator/v10"
	"plugins/zltx_card/internal/vo"
)

type Card struct {
	Number   string `json:"number"`
	Password string `json:"password"`
}

func (c *Card) ToString() string {
	bytes, _ := json.Marshal(c)
	return string(bytes)
}

type Req interface {
	Validate() error
}

var _ Req = (*OrderReq)(nil)
var _ Req = (*QueryReq)(nil)
var _ Req = (*Notify)(nil)

func (req *OrderReq) Validate() error {
	err := validator.New().Struct(req)
	if err != nil {
		for _, err = range err.(validator.ValidationErrors) {
			return fmt.Errorf("参数有误：" + err.Error())
		}
	}
	return nil
}

func (req *QueryReq) Validate() error {
	err := validator.New().Struct(req)
	if err != nil {
		for _, err = range err.(validator.ValidationErrors) {
			return fmt.Errorf("参数有误：" + err.Error())
		}
	}
	return nil
}

func (req *Notify) Validate() error {
	err := validator.New().Struct(req)
	if err != nil {
		for _, err = range err.(validator.ValidationErrors) {
			return fmt.Errorf("参数有误：" + err.Error())
		}
	}
	return nil
}

type Resp interface {
	SetCodeStr()
}

var _ Resp = (*OrderResp)(nil)

func (r *OrderResp) SetCodeStr() {
	r.CodeStr = vo.Code(fmt.Sprintf("%v", r.Code))
}
